'Name: RWSD75iFix.vbs
'Parameters: None
'Version: 1.00.00
'Date: 2016-07-05 (Updated on 5/1/2017)
'Original Author: Chacal

'Modified by: Sage (TheRealSFC)
'Railworks America URL: http://www.RailworksAmerica.com
'RoadRailer Simulations URL: http://www.sagefun.com/RRS

'Purpose: Use this script for fixing absolute paths to texture files 
'in RSC's SD75i's geopcdx file. This will allow repainting the SD75i.

'initialize globals --------------------
Dim g_xmlConfig, g_gamePath, g_configFileName, g_logFileName, g_cancel, result, g_objProgressMsg _
    , g_SourceGeoPath, g_Dest1GeoPath, g_Dest2GeoPath, g_SourceGeoCabPath, g_Dest1GeoCabPath, g_Dest2GeoCabPath, geoString
g_configFileName = "RWLibConfig.xml"
g_logFileName = "RWSD75iFix.log"
g_cancel = False

'Include "RWLib.vbs"
'Include "RWLibGUI.vbs"

WriteLog "RWSD75iFix: Start " & "-----------------------------------------------------------------"
'Get or create user local configuration 
result=GetUserConfig (g_configFileName)
If g_cancel Then
   Cancel
End If

'Geo file paths
g_SourceGeoPath = g_gamePath & "\Assets\RSC\SD75Pack01\RailVehicles\Diesel\SD75I\Default\Engine\SD75_I_BNSF.GeoPcDx"
g_Dest1GeoPath = g_gamePath & "\Assets\RSC\SD75Pack01\RailVehicles\Diesel\SD75I\CN\Engine\SD75_I_BNSF.GeoPcDx"
g_Dest2GeoPath = g_gamePath & "\Assets\RSC\SD75Pack01\RailVehicles\Diesel\SD75I\CN_URL\Engine\SD75_I_BNSF.GeoPcDx"

'Geo Cab file paths
g_SourceGeoCabPath = g_gamePath & "\Assets\RSC\SD75Pack01\RailVehicles\Diesel\SD75M\Default\CabView\sd75cab.GeoPcDx"
g_Dest1GeoCabPath = g_gamePath & "\Assets\RSC\SD75Pack01\RailVehicles\Diesel\SD75I\CN\CabView\sd75cab.GeoPcDx"
g_Dest2GeoCabPath = g_gamePath & "\Assets\RSC\SD75Pack01\RailVehicles\Diesel\SD75I\CN_URL\CabView\sd75cab.GeoPcDx"

ProgressMsg "Processing file, please wait.", "RWSD75iFix"

'Copy the CabView geo file from Default to CN
If Not CopyFile (g_SourceGeoCabPath, g_Dest1GeoCabPath) Then
   WriteLog "RWSD75iFix: ERROR can't copy geopcdx file to " & g_Dest1GeoCabPath
   Abort
End If

'Copy the CabView geo file from Default to CN_URL
If Not CopyFile (g_SourceGeoCabPath, g_Dest2GeoCabPath) Then
   WriteLog "RWSD75iFix: ERROR can't copy geopcdx file to " & g_Dest2GeoCabPath
   Abort
End If

'Copy the geo file from Default to CN
If Not CopyFile (g_SourceGeoPath, g_Dest1GeoPath & ".bin") Then
   WriteLog "RWSD75iFix: ERROR can't copy geopcdx file to " & g_Dest1GeoPath & ".bin"
   Abort
End If

' Decompile into xml file
If Not Decompile (g_Dest1GeoPath & ".bin") Then
   WriteLog "RWSD75iFix: ERROR can't decompile geopcdx file " & g_Dest1GeoPath & ".bin"
   Abort
End If

'Read the XML file 
If Not ReadFileIntoString (g_Dest1GeoPath & ".xml",geoString,False) Then
   WriteLog "RWSD75iFix: ERROR can't read xml file " & g_Dest1GeoPath & ".xml"
   Abort
End If

'Replace strings
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]extras","textures\[00]extras")
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]sd70mac_under_01","textures\[00]sd70mac_under_01")
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]sd70mac_under_02","textures\[00]sd70mac_under_02")
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]bogie_ex","textures\[00]bogie_ex")
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]main_bogie","textures\[00]main_bogie")
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]brazo_piston","textures\[00]brazo_piston")
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]cadena","textures\[00]cadena")
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]pistones","textures\[00]pistones") 
geoString = Replace(geoString,"..\..\..\sd75m\default\engine\textures\[00]wheel","textures\[00]wheel")

'Write the XML file from string
If Not WriteFileFromString (g_Dest1GeoPath & ".xml",geoString) Then
   WriteLog "RWSD75iFix: ERROR can't write xml file " & g_Dest1GeoPath & ".xml"
   Abort
End If

' Recompile into bin file
If Not Decompile (g_Dest1GeoPath & ".xml") Then
   WriteLog "RWSD75iFix: ERROR can't recompile xml file " & g_Dest1GeoPath & ".xml"
   Abort
End If

'Delete the xml file
If Not DeleteFile (g_Dest1GeoPath & ".xml") Then
   WriteLog "RWSD75iFix: Warning can't delete xml file " & g_Dest1GeoPath & ".xml"
End If

'Rename the .bin file to .geopcdx
If Not MoveFile (g_Dest1GeoPath & ".bin", g_Dest1GeoPath) Then
   WriteLog "RWSD75iFix: ERROR can't rename bin file " & g_Dest1GeoPath & ".bin"
   Abort
End If

'Copy the geo file from CN to CN_URL
If Not CopyFile (g_Dest1GeoPath,g_Dest2GeoPath) Then
   WriteLog "RWSD75iFix: ERROR can't copy geopcdx file to " & g_Dest2GeoPath
   Abort
End If

ProgressMsg "", "RWSD75iFix"
GUIShowLogSuccess

'Wrap up
Set g_xmlConfig = Nothing
WriteLog "RWSD75iFix: End" & "-----------------------------------------------------------------"

'All done.
'End main program


'---------------------------------------------------------------------------
'RWLib.vbs
'Version 1.00.00
'Script library for RailWorks XML files
'Chacal 2013

' Abort
' AddQuotes(strInput)
' Cancel
' CheckFile (Filename, CheckIfWriteable, TreatDirAsFile)
' CheckTag (tag, fileCount)
' CopyFile (fromPath,toPath)
' CreateConfig (fname)
' CreateDir (path)
' CurrentDirectory
' Decompile (fileName,tempfileName)
' DeleteFile (fileName)
' GetConfig (key)
' GetUserConfig (fname)
' GetXmlDoc (xmlObj,fname)
' IsPathWriteable(Path)
' IsXmlFile (path)
' MoveFile (fromPath, toPath)
' ProgressMsg( strMessage, strWindowTitle )
' ReadFileIntoString (fileName,txt)
' ReadFromRegistry (strRegistryKey, strDefault )
' Run (fname)
' SetConfig (key, newValue)
' SetXmlConfig (fname)
' WriteLog(message)


Sub Abort
   'Show log, clean up, quit.
   ProgressMsg "", "RWSD75iFix"
   Set g_xmlConfig = Nothing
   WriteLog "RWSD75iFix: Aborted" & "--------------------------------------------------------"
   GUIShowLogError
   Wscript.Quit
End Sub

Function AddQuotes(strInput)
    ' add leading and trailing quotes to string passed into the function and return
    AddQuotes = Chr(34) & strInput & Chr(34)
End Function

Sub Cancel
   'User has hit a Cancel button
   WriteLog "RWSD75iFix: Operation cancelled by user."
   WriteLog "RWSD75iFix: End" & "-----------------------------------------------------------------"
   Wscript.Echo "Processing cancelled." & vbcrlf & "No changes will be written."
   Wscript.Quit
End Sub

Function CheckFile(fileName, CheckIfWriteable, TreatDirAsFile)
' Returns true if Filename exists. If Filename is a directory and
' TreatDirAsFile is true then the function will also return true.
' Similarly if the file is really a directory and TreatDirAsFile is false
' then the function will return false. If the file is read-only and 
' CheckIfWriteable is true, then the function will return false.
   On Error Resume Next
   Err.Clear
   Dim Attributes, filesys, f
   CheckFile = True   
   Set filesys=CreateObject("Scripting.FileSystemObject")
   Set f = filesys.GetFile(fileName) ' will throw an error if it doesn't exist
   If  Err.Number <> 0  Then
      ' error thrown at GetFile, file doesn't exist
      WriteLog "        CheckFile: File not found: " & fileName
      CheckFile = False
   Else
      If f.attributes And 1 And CheckIfWriteable Then
         CheckFile = False ' it is not writeable
      End If
      If f.attributes And 16 And Not TreatDirAsFile Then
         CheckFile = False ' it's a directory but that's not cool
      Else
         CheckFile = True ' it's a directory but we said that's cool
      End If
   End If
   Set filesys = Nothing
End Function

Function CopyFile (fromPath,toPath)
   'copies a file
   On Error Resume Next
   Err.Clear
   Dim filesys,f
   Set filesys=CreateObject("Scripting.FileSystemObject")
   Set f = filesys.GetFile(fromPath) ' will throw an error if it doesn't exist
   If  Err.Number <> 0  Then
      ' error thrown at GetFile, file doesn't exist
      WriteLog "        CopyFile: File not found: " & fromPath
      CopyFile = False
   Else
      WriteLog "        CopyFile: Copying file " & fromPath & " to " & toPath
      filesys.CopyFile fromPath, toPath ,1
      CopyFile = True
   End If
   Set filesys = Nothing
End Function

Function CreateConfig (fileName)
   'Creates the config file
   Dim xmlDoc, objRoot, objPI, objNode1, objNode2, objText, gamePath
   CreateConfig = False
   ' Get the default game path from the registry
   WriteLog "    CreateConfig: reading Steam path from registry" 
   gamePath = ReadFromRegistry ("HKEY_CURRENT_USER\Software\Valve\Steam\SteamPath", "")
   gamePath=Replace (gamePath,"/","\")
   WriteLog "    CreateConfig: Steam path is " & gamePath
   If gamePath <> "" Then
      gamePath = gamePath & "\steamapps\common\railworks"
   End If
   Writelog "CreateConfig: Start creating config xml file"
   If Not DeleteFile (fileName) Then
      'Don't care
   End If
   Set xmlDoc = Nothing
   Set xmlDoc = CreateObject("Microsoft.XMLDOM")  
   xmlDoc.preserveWhiteSpace = true

   Set objPI = xmlDoc.createProcessingInstruction("xml", " version = ""1.0""")
   xmlDoc.insertBefore objPI, xmlDoc.firstChild

   Set objRoot = xmlDoc.createElement("config")
   xmlDoc.appendChild objRoot 

   objRoot.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode1 = xmlDoc.createElement ("version")
   Set objText = xmlDoc.createTextNode ("1.0")
   objNode1.appendChild (objText)
   objRoot.appendChild (objNode1)

   objRoot.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode1 = xmlDoc.createElement ("name")
   Set objText = xmlDoc.createTextNode ("UserConfig")
   objNode1.appendChild (objText)
   objRoot.appendChild (objNode1)
   
   objRoot.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode1 = xmlDoc.createElement ("author")
   Set objText = xmlDoc.createTextNode ("Chacal")
   objNode1.appendChild (objText)
   objRoot.appendChild (objNode1)
   
   objRoot.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode1 = xmlDoc.createElement ("date")
   Set objText = xmlDoc.createTextNode ("2013-09-28")
   objNode1.appendChild (objText)
   objRoot.appendChild (objNode1)
   
   objRoot.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode1 = xmlDoc.createElement ("description")
   Set objText = xmlDoc.createTextNode ("RWLib user configuration")
   objNode1.appendChild (objText)
   objRoot.appendChild (objNode1)

   objRoot.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode1 = xmlDoc.createElement ("clientconfig")
   objRoot.appendChild (objNode1)
   
   objNode1.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode2 = xmlDoc.createElement ("gamepath")
   Set objText = xmlDoc.createTextNode (gamePath)
   objNode2.appendChild (objText)
   objNode1.appendChild (objNode2)

   objNode1.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   Set objNode2 = xmlDoc.createElement ("decompilecmd")
   Set objText = xmlDoc.createTextNode (gamePath & "\serz.exe")
   objNode2.appendChild (objText)
   objNode1.appendChild (objNode2)
   objNode1.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))
   objRoot.appendChild(xmlDoc.createTextNode(vbCrLf & vbTab))

   xmlDoc.Save fileName
   CreateConfig = True
   Writelog "CreateConfig: End creating config xml file "
End Function

Function CurrentDirectory
   ' Returns current directory
   CurrentDirectory = left(WScript.ScriptFullName,(Len(WScript.ScriptFullName))- _
      (len(WScript.ScriptName)))
End Function

Function Decompile (fileName)
   'Decompile a bin file
   Dim WshShell, intResult, decompileCmd, Command
   decompileCmd = GetConfig ("decompilecmd")
   command = AddQuotes (decompileCmd) & " " & AddQuotes (fileName)
   Set WshShell = WScript.CreateObject("WScript.Shell")
   WriteLog "        Decompile: Trying " & command
   intResult = WshShell.Run (command, 0, TRUE)
   If intResult Then
      WriteLog "        Decompile: Error - Decompile returned " & intResult
      Decompile = False
   Else
      Decompile = True
      WriteLog "        Decompile: Seems to have completed successfully "
   End If
   Set WshShell = Nothing
End Function

Function DeleteFile (fileName)
   'deletes a file 
   On Error Resume Next
   Err.Clear
   dim filesys
   Set filesys=CreateObject("Scripting.FileSystemObject")
   Set f = filesys.GetFile(fileName) ' will throw an error if it doesn't exist
   If  Err.Number <> 0  Then
      ' error thrown at GetFile, file doesn't exist
      WriteLog "        DeleteFile: File not found: " & fileName
      DeleteFile = False
   Else
      WriteLog "        DeleteFile: Deleting file " & fileName
      filesys.DeleteFile fileName
      DeleteFile = True
   End If
   Set filesys = Nothing
End Function

Function GetConfig (key)
   'returns value of child of node /config/clientconfig
   Dim currNode
   Set currNode = g_xmlConfig.selectSingleNode("/config/clientconfig/" & key)
   GetConfig = currNode.Text
   Set currNode = Nothing
End Function

Function GetUserConfig (fname)
   'Get the user local config, with confirmation
   'Return false if a path is still empty
   Dim result
   WriteLog "    GetUserConfig: reading user configuration" 
   Set g_xmlConfig=CreateObject("Microsoft.XMLDOM")
   If Not GetXmlDoc (g_xmlConfig,fname) Then
      'the config file is corrupted or doesn't exist; create a new one
      If Not CreateConfig (fname) Then
      	 'Could not create the config file
      	 Abort
      Else
         result = GetXmlDoc (g_xmlConfig,fname)
      End If
   End If
   g_gamePath = GetConfig ("gamepath")
   result = GUIGetUserConfig ()
   SetXmlConfig (fname)
   result = GetXmlDoc (g_xmlConfig,fname)
   If (g_gamePath = "") Then
      GetUserConfig = False
   Else
      GetUserConfig = True
   End If
End Function

Function GetXmlDoc (xmlObj,fname)
   'reads an entire XML file into a XML DOM object
   Dim result, filesys
   GetXmlDoc = True
   xmlObj.async="false"
   set filesys=CreateObject("Scripting.FileSystemObject")
   If Not filesys.FileExists(fname) Then
      Writelog "    GetXmlDoc: Error - The xml file " & fname & " doesn't exist!"
      GetXmlDoc = False
      Exit Function
   Else	
      Writelog "    GetXmlDoc: reading xml file " & fname 
      xmlObj.load(fname)
      If xmlObj.parseError.errorCode Then
      ' Do something with the error.
         result= "        Parse Error: " & vbcrlf & _ 
                      "                               Reason = "  & xmlObj.parseError.reason & vbcrlf & _ 
                      "                               Line = "    & xmlObj.parseError.line & vbcrlf & _ 
                      "                               linePos = " & xmlObj.parseError.linePos & vbcrlf & _ 
                      "                               srcText = " & xmlObj.parseError.srcText & vbcrlf & _ 
                      "                               ErrorCode = " & xmlObj.parseError.ErrorCode & vbcrlf
         WriteLog result
         GetxmlObj = False
      End If
   End If
   xmlObj.setProperty "SelectionLanguage", "XPath"
   Set filesys = Nothing
End Function

Function IsPathWriteable(Path)' As Boolean
    'Checks that we have write access to Path
    Dim fso 'As Scripting.FileSystemObject
    Dim Temp_Path 'As String
    Set fso = CreateObject("Scripting.FileSystemObject")
    Temp_Path = Path & "\" & fso.GetTempName() & ".tmp"
     On Error Resume Next
        fso.CreateTextFile Temp_Path
        IsPathWriteable = Err.Number = 0
        fso.DeleteFile Temp_Path
    On Error Goto 0
End Function

Function IsXmlFile (path)
   ' Check if file has xml header
   ' Open file and read into a string
   Dim text, posTxt
   If Not ReadFileIntoString (path, text,5) Then
      WriteLog "        IsXmlFile: Error reading file " & path
      Exit Function
   End If
   ' Search text for specific signature
   posTxt=InStrRev(text,"<?xml")
   If posTxt Then
      IsXmlFile = True
   Else
      IsXmlFile = False
   End If
End Function

Function MoveFile (fromPath, toPath)
   ' Move or rename file
   On Error Resume Next
   Err.Clear
   Dim Fso,f
   Set Fso = WScript.CreateObject("Scripting.FileSystemObject")
   Set f = Fso.GetFile(fromPath) ' will throw an error if it doesn't exist
   If  Err.Number <> 0  Then
      ' error thrown at GetFile, file doesn't exist
      WriteLog "        MoveFile: File not found: " & fromPath
      MoveFile = False
   Else
      WriteLog "        MoveFile: Moving file " & fromPath & " to " & toPath
      Fso.MoveFile fromPath, toPath
      MoveFile = True
   End If
   Set Fso = Nothing
End Function

Function ProgressMsg( strMessage, strWindowTitle )
' Written by Denis St-Pierre
' Displays a progress message box that the originating script can kill in both 2k and XP
' If StrMessage is blank, take down previous progress message box
' Using 4096 in Msgbox below makes the progress message float on top of things
' CAVEAT: You must have   Dim g_objProgressMsg   at the top of your script for this to work as described
    Set wshShell = WScript.CreateObject( "WScript.Shell" )
    strTEMP = wshShell.ExpandEnvironmentStrings( "%TEMP%" )
    If strMessage = "" Then
        ' Disable Error Checking in case g_objProgressMsg doesn't exists yet
        On Error Resume Next
        ' Kill ProgressMsg
        g_objProgressMsg.Terminate( )
        ' Re-enable Error Checking
        On Error Goto 0
        Exit Function
    End If
    Set objFSO = CreateObject("Scripting.FileSystemObject")
    strTempVBS = strTEMP + "\" & "Message.vbs"     'Control File for reboot

    ' Create Message.vbs, True=overwrite
    Set objTempMessage = objFSO.CreateTextFile( strTempVBS, True )
    objTempMessage.WriteLine( "MsgBox""" & strMessage & """, 4096, """ & strWindowTitle & """" )
    objTempMessage.Close

    ' Disable Error Checking in case g_objProgressMsg doesn't exists yet
    On Error Resume Next
    ' Kills the Previous ProgressMsg
    g_objProgressMsg.Terminate( )
    ' Re-enable Error Checking
    On Error Goto 0

    ' Trigger g_objProgressMsg and keep an object on it
    Set g_objProgressMsg = WshShell.Exec( "%windir%\system32\wscript.exe " & strTempVBS )

    Set wshShell = Nothing
    Set objFSO   = Nothing
End Function

Function ReadFileIntoString (fileName,txt,numOfChars)
   'Reads a text file into a string
   Const ForReading = 1
   Dim WshShell, objFSO, objFile
   ReadFileIntoString = False
   Set objFSO = CreateObject("Scripting.FileSystemObject")
   If Not objFSO.FileExists(fileName) Then
      Writelog "    ReadFileIntoString: File doesn't exist: " & fileName
   Else
      On Error Resume Next
      Set objFile = objFSO.OpenTextFile(fileName, ForReading)
      WriteLog "    ReadFileIntoString: Reading text from file " & fileName
      If numOfChars Then
         txt = objFile.Read(numOfChars)
      Else
         txt = objFile.ReadAll
      End If
      If Err.Number Then
         ReadFileIntoString = False
         Writelog "    ReadFileIntoString: Error reading file: " & err.description
      Else 
         ReadFileIntoString = True
         objFile.Close
      End If
      Set ObjFSO = Nothing
      Set ObjFile = Nothing
      On Error Goto 0
   End If
End Function

Function ReadFromRegistry (strRegistryKey, strDefault )
    'Usage: str = ReadFromRegistry("HKEY_LOCAL_MACHINE\SOFTWARE\Adobe\ESD\Install_Dir", "Empty")
    Dim WSHShell, value

    On Error Resume Next
    Set WSHShell = CreateObject("WScript.Shell")
    value = WSHShell.RegRead( strRegistryKey )

    if err.number <> 0 then
        ReadFromRegistry= strDefault
    else
        ReadFromRegistry=value
    end if

    set WSHShell = nothing
End Function

Sub Run (fname)
   Set objShell = CreateObject("WScript.Shell")
   'strcommandline = AddQuotes (fname)
   strcommandline = fname
   objShell.Run(strcommandline)
End Sub

Sub SetConfig (key, newValue)
   'replaces value of node /config/clientconfig/key with newValue
   ' Does not write back to the Xml file. Use SetXmlConfig for that after all changes.
   Dim currNode
   Set currNode = g_xmlConfig.selectSingleNode("/config/clientconfig/" & key)
   currNode.Text = newValue
End Sub

Sub SetXmlConfig (fname)
   'writes the g_xmlConfig public object back to file fname
   g_xmlConfig.Save fname
End Sub

Function WriteFileFromString (path,string)
   'Writes a string to a text file
   Dim ObjFSO, ObjFile
   Set ObjFso = CreateObject("Scripting.FileSystemObject")
   Set ObjFile = ObjFso.CreateTextFile(path)
   WriteLog "    WriteFileFromString: Writing text to file " & path
   On Error Resume Next
   ObjFile.Write(string)
   If Err.Number Then
      WriteFileFromString = False
   Else 
      WriteFileFromString = True
      ObjFile.Close
   End If
   Set ObjFSO = Nothing
   Set ObjFile = Nothing
   On Error Goto 0
End Function

Sub WriteLog(message)
   'appends message to log file; creates file if needed
   Dim objFSO, objFile
   Set objFSO  = CreateObject("Scripting.FileSystemObject")
   Set objFile = objFSO.OpenTextFile(g_logFileName, 8, True)
   objFile.WriteLine Now() & "    " & message
   objFile.Close
   Set objFile = Nothing
   Set objFSO  = Nothing
End Sub

' --------------------------------------------------------------------------
'RWLibGUI.vbs
'Script library for Railworks XML
'Chacal 2013

' GUIBrowseForFile()
' GUIBrowseFolder( myStartLocation, blnSimpleDialog )
' GUIGetRWPath (defaultPath)
' GUIGetUserConfig
' GUIShowLogError
' GUIShowLogSuccess

Function GUIBrowseForFile()
'Ugly hack of a function for a file browser that works in Windows after XP
'Bypasses IE7+ c:\fakepath\file.txt problem
    With CreateObject("WScript.Shell")
        Dim fso : Set fso = CreateObject("Scripting.FileSystemObject")
        Dim tempFolder : Set tempFolder = fso.GetSpecialFolder(2)
        Dim tempName : tempName = fso.GetTempName() & ".hta"
        Dim path : path = "HKCU\Volatile Environment\MsgResp"
        With tempFolder.CreateTextFile(tempName)
            .Write "<input type=file name=f>" & _
            "<script>f.click();(new ActiveXObject('WScript.Shell'))" & _
            ".RegWrite('HKCU\\Volatile Environment\\MsgResp', f.value);" & _
            "close();</script>"
            .Close
        End With
        .Run tempFolder & "\" & tempName, 1, True
        GUIBrowseForFile = .RegRead(path)
        .RegDelete path
        fso.DeleteFile tempFolder & "\" & tempName
    End With
End Function

Function GUIBrowseFolder( myStartLocation, blnSimpleDialog )
' This function generates a Browse Folder dialog
' and returns the selected folder as a string.
'
' Arguments:
' myStartLocation   [string]  start folder for dialog, or "My Computer", or
'                             empty string to open in "Desktop\My Documents"
' blnSimpleDialog   [boolean] if False, an additional text field will be
'                             displayed where the folder can be selected
'                             by typing the fully qualified path
'
' Returns:          [string]  the fully qualified path to the selected folder
'
' Based on the Hey Scripting Guys article
' "How Can I Show Users a Dialog Box That Only Lets Them Select Folders?"
' http://www.microsoft.com/technet/scriptcenter/resources/qanda/jun05/hey0617.mspx
'
' Function written by Rob van der Woude
' http://www.robvanderwoude.com
    Const MY_COMPUTER   = &H11&
    Const WINDOW_HANDLE = 0 ' Must ALWAYS be 0
    Dim numOptions, objFolder, objFolderItem
    Dim objPath, objShell, strPath, strPrompt
    ' Set the options for the dialog window
    strPrompt = "Select a folder:"
    If blnSimpleDialog = True Then
        numOptions = 0      ' Simple dialog
    Else
        numOptions = &H10&  ' Additional text field to type folder path
    End If
    ' Create a Windows Shell object
    Set objShell = CreateObject( "Shell.Application" )
    ' If specified, convert "My Computer" to a valid
    ' path for the Windows Shell's BrowseFolder method
    If UCase( myStartLocation ) = "MY COMPUTER" Then
        Set objFolder = objShell.Namespace( MY_COMPUTER )
        Set objFolderItem = objFolder.Self
        strPath = objFolderItem.Path
    Else
        strPath = myStartLocation
    End If
    Set objFolder = objShell.BrowseForFolder( WINDOW_HANDLE, strPrompt, _
                                              numOptions, strPath )
    ' Quit if no folder was selected
    If objFolder Is Nothing Then
        GUIBrowseFolder = ""
        g_cancel = True
        Exit Function
    End If
    ' Retrieve the path of the selected folder
    Set objFolderItem = objFolder.Self
    objPath = objFolderItem.Path
    ' Return the path of the selected folder
    GUIBrowseFolder = objPath
End Function

Function GUIGetRWPath (defaultPath)
   'Select Railworks folder
   'Also check if the DB file exists and is writeable and we have write access to folder
   Dim title, prompt, result, RWpath, fileExists
   title = "Select Railworks folder"
   prompt = "In the next step, please select the Railworks program folder"
   result = MsgBox (prompt, vbOkCancel + vbInformation, title)
   Select Case result
      Case vbCancel
         g_cancel = True
      Case vbOk
         Do
            RWPath = GUIBrowseFolder (defaultPath, False)
            If g_cancel Then
               GUIGetRWPath = ""
               Exit Do
            ElseIf Not IsPathWriteable(RWpath & "\Content") Then      
               fileExists = False
               prompt = "Content folder not found or not writeable: " & vbcrlf & RWpath & "\Content"
               result = MsgBox (prompt, vbOK + vbCritical, title)
            ElseIf CheckFile (RWpath & "\Content\SDBCache.bin", True, False) Then
               GUIGetRWPath = RWpath
               fileExists = True
            Else
               fileExists = False
               prompt = "Current database file not found or not writeable: " & vbcrlf & _
                  RWpath & "\Content\SDBCache.bin"
               result = MsgBox (prompt, vbOK + vbCritical, title)
            End If
         Loop Until fileExists
   End Select
End Function

Function GUIGetUserConfig
'Get user local configuration
   Dim title, prompt, result, browseFolder
   GUIGetUserConfig = True
   'Configure game path
   title = "Choose Railworks folder"
   If g_gamePath = "" Then
      browseFolder = True
   Else     	
      prompt = "The current Railworks folder is:" & vbcrlf & g_gamePath & _
         vbcrlf & vbcrlf & "Would you like to change this ?"
      result = MsgBox (prompt, vbYesNo + vbInformation + + vbDefaultButton2, title)
      Select Case result
      Case vbNo
         browseFolder = False
         GUIGetUserConfig = True
      Case vbYes
         browseFolder = True
      End Select
   End If
   If browseFolder Then
      g_gamePath = GUIGetRWPath (DESKTOP)
      If g_cancel Then
         GUIGetUserConfig = False
      Else
         SetConfig "gamepath" , g_gamePath
         GUIGetUserConfig = True
      End If
   End If
End Function

Sub GUIShowLogError
   'Show fatal error message and show log in Notepad if desired
   Dim prompt, title, result
   title = "Fatal Error"
   prompt = "A fatal error happened. RWSD75iFix cannot perform the operation." _
      & vbcrlf & vbcrlf &_
   "Do you want to see the log ? "
   result = MsgBox (prompt, vbYesNo + vbCritical, title)
   Select Case result
   Case vbYes
      Run "notepad " & g_logFileName
   Case vbNo
   End Select
End Sub

Sub GUIShowLogSuccess
   'Show success message and show log in Notepad if desired
   Dim prompt, title, result
   title = "Operation completed"
   prompt = "RWSD75iFix has completed the operation successfully." & vbcrlf & vbcrlf &_
      "Do you want to see the log ? "
   result = MsgBox (prompt, vbYesNo + vbInformation, title)
   Select Case result
   Case vbYes
      Run "notepad " & g_logFileName
   Case vbNo
   End Select
End Sub
